@@ -27,8 +27,8 @@
 #include <vector>
 #include <deque>
 
-#include <pan/general/foreach.h>
 #include <pan/general/quark.h>
+#include <pan/general/macros.h>
 #include <pan/general/map-vector.h>
 #include <pan/general/sorted-vector.h>
 #include <pan/usenet-utils/numbers.h>
@@ -574,7 +574,7 @@ namespace pan
                                          const Quark          & group,
                                          const StringView     & subject,
                                          const StringView     & author,
-                                         const StringView     & date,
+                                         const time_t           date,
                                          const StringView     & message_id,
                                          const StringView     & references,
                                          const unsigned long    byte_count,
