@@ -22,7 +22,7 @@
 #include <algorithm>
 #include <glib.h>
 #include <pan/general/debug.h>
-#include <pan/general/foreach.h>
+#include <pan/general/macros.h>
 #include <pan/general/string-view.h>
 #include "article.h"
 
