@@ -50,8 +50,8 @@ namespace pan
       GtkWidget* get_default_focus_widget() { return _tree_view; }
       GtkWidget* create_filter_entry ();
       void set_name_collapse (bool);
-      Quark get_selection () const;
-      quarks_t get_full_selection () const;
+      Quark get_first_selection () const;
+      quarks_v get_full_selection () const;
       void read_next_unread_group ();
       void read_next_group ();
 
@@ -82,9 +82,9 @@ namespace pan
 
     private:
       virtual void on_prefs_flag_changed (const StringView& key, bool value);
-      virtual void on_prefs_int_changed (const StringView& key, int color) { }
+      virtual void on_prefs_int_changed (const StringView&, int) { }
       virtual void on_prefs_string_changed (const StringView& key, const StringView& value);
-      virtual void on_prefs_color_changed (const StringView& key, const GdkColor& color) { }
+      virtual void on_prefs_color_changed (const StringView&, const GdkColor&) { }
 
     private:
       quarks_t _dirty_groups;
