@@ -158,6 +158,10 @@ struct PanTreeStore
         int child_index;
 
       private:
+        Row* get_last_descendant () {
+          return children.empty() ? this
+                                  : children.back()->get_last_descendant ();
+        }
         int n_children () const {
           return (int) children.size();
         }
@@ -198,6 +202,13 @@ struct PanTreeStore
     /** Build a GtkTreePath corresponding to the Row */
     GtkTreePath* get_path (const Row* row) const;
 
+    bool back (GtkTreeIter * iter);
+    bool front (GtkTreeIter * iter);
+    bool get_next (GtkTreeIter * iter);
+    bool get_prev (GtkTreeIter * iter);
+    Row*  get_next (Row * iter);
+    Row*  get_prev (Row * iter);
+
   public:
 
     typedef std::map<Row*,rows_t> parent_to_children_t;
@@ -230,7 +241,6 @@ struct PanTreeStore
 
   public:
 
-    void sort ();
     void pause_sorting () { ++sort_paused; }
     void resume_sorting () { if (!--sort_paused) sort (); }
 
@@ -288,6 +298,9 @@ struct PanTreeStore
 
   private:
 
+    enum { SORT, FLIP };
+    void sort (int mode=SORT);
+
     /**
      * Per-row sorting information, as set by
      * gtk_tree_sortable_set_sort_func().
@@ -336,6 +349,8 @@ struct PanTreeStore
 
     static void invalidate_iter (GtkTreeIter*);
 
+    bool set_or_invalidate (GtkTreeIter*, const Row*);
+
   private:
 
     void remove (const rows_t& rows, bool delete_rows);
@@ -435,7 +450,7 @@ struct PanTreeStore
   private:
     struct SortData;
     struct SortRowInfo;
-    void sort_children (SortInfo&, Row* parent, bool recurse);
+    void sort_children (SortInfo&, Row* parent, bool recurse, int mode);
     static int row_compare_func (gconstpointer, gconstpointer, gpointer);
 
   private:
