@@ -31,8 +31,8 @@ extern "C" {
 }
 #include <pan/general/debug.h>
 #include <pan/general/file-util.h>
-#include <pan/general/foreach.h>
 #include <pan/general/log.h>
+#include <pan/general/macros.h>
 #include <pan/general/utf8-utils.h>
 #include <pan/usenet-utils/gnksa.h>
 #include <pan/usenet-utils/message-check.h>
@@ -53,6 +53,10 @@ extern "C" {
 #define DEFAULT_SPELLCHECK_FLAG false
 #endif
 
+#if !GTK_CHECK_VERSION(2,6,0)
+#define GTK_STOCK_EDIT GTK_STOCK_OPEN
+#endif
+
 using namespace pan;
 
 #define USER_AGENT_PREFS_KEY "add-user-agent-header-when-posting"
@@ -62,7 +66,7 @@ namespace
 {
   bool remember_charsets (true);
 
-  void on_remember_charset_toggled (GtkToggleAction * toggle, gpointer post_g)
+  void on_remember_charset_toggled (GtkToggleAction * toggle, gpointer)
   {
     remember_charsets = gtk_toggle_action_get_active (toggle);
   }
@@ -177,49 +181,49 @@ namespace
 {
   GtkWidget* get_focus (gpointer p) { return gtk_window_get_focus(GTK_WINDOW(static_cast<PostUI*>(p)->root())); }
 
-  void do_cut      (GtkAction * w, gpointer p) { g_signal_emit_by_name (get_focus(p), "cut_clipboard"); }
-  void do_copy     (GtkAction * w, gpointer p) { g_signal_emit_by_name (get_focus(p), "copy_clipboard"); }
-  void do_paste    (GtkAction * w, gpointer p) { g_signal_emit_by_name (get_focus(p), "paste_clipboard"); }
-  void do_rot13    (GtkAction * w, gpointer p) { static_cast<PostUI*>(p)->rot13_selection(); }
-  void do_edit     (GtkAction * w, gpointer p) { static_cast<PostUI*>(p)->spawn_editor (); }
-  void do_profiles (GtkAction * w, gpointer p) { static_cast<PostUI*>(p)->manage_profiles (); }
-  void do_send     (GtkAction * w, gpointer p) { static_cast<PostUI*>(p)->send_now (); }
-  void do_save     (GtkAction * w, gpointer p) { static_cast<PostUI*>(p)->save_draft (); }
-  void do_open     (GtkAction * w, gpointer p) { static_cast<PostUI*>(p)->open_draft (); }
-  void do_charset  (GtkAction * w, gpointer p) { static_cast<PostUI*>(p)->prompt_for_charset (); }
-  void do_close    (GtkAction * w, gpointer p) { static_cast<PostUI*>(p)->close_window (); }
+  void do_cut      (GtkAction*, gpointer p) { g_signal_emit_by_name (get_focus(p), "cut_clipboard"); }
+  void do_copy     (GtkAction*, gpointer p) { g_signal_emit_by_name (get_focus(p), "copy_clipboard"); }
+  void do_paste    (GtkAction*, gpointer p) { g_signal_emit_by_name (get_focus(p), "paste_clipboard"); }
+  void do_rot13    (GtkAction*, gpointer p) { static_cast<PostUI*>(p)->rot13_selection(); }
+  void do_edit     (GtkAction*, gpointer p) { static_cast<PostUI*>(p)->spawn_editor (); }
+  void do_profiles (GtkAction*, gpointer p) { static_cast<PostUI*>(p)->manage_profiles (); }
+  void do_send     (GtkAction*, gpointer p) { static_cast<PostUI*>(p)->send_now (); }
+  void do_save     (GtkAction*, gpointer p) { static_cast<PostUI*>(p)->save_draft (); }
+  void do_open     (GtkAction*, gpointer p) { static_cast<PostUI*>(p)->open_draft (); }
+  void do_charset  (GtkAction*, gpointer p) { static_cast<PostUI*>(p)->prompt_for_charset (); }
+  void do_close    (GtkAction*, gpointer p) { static_cast<PostUI*>(p)->close_window (); }
   void do_wrap     (GtkToggleAction * w, gpointer p) { static_cast<PostUI*>(p)->set_wrap_mode (gtk_toggle_action_get_active (w)); }
   void do_edit2    (GtkToggleAction * w, gpointer p) { static_cast<PostUI*>(p)->set_always_run_editor (gtk_toggle_action_get_active (w)); }
 
   GtkActionEntry entries[] =
   {
-    { "file-menu", NULL, N_("_File") },
-    { "edit-menu", NULL, N_("_Edit") },
-    { "profile-menu", NULL, N_("_Profile") },
-    { "editors-menu", NULL, N_("Set Editor") },
-    { "post-toolbar", NULL, "post" },
+    { "file-menu", 0, N_("_File"), 0, 0, 0 },
+    { "edit-menu", 0, N_("_Edit"), 0, 0, 0 },
+    { "profile-menu", 0, N_("_Profile"), 0, 0, 0 },
+    { "editors-menu", 0, N_("Set Editor"), 0, 0, 0 },
+    { "post-toolbar", 0, "post", 0, 0, 0 },
     { "post-article", GTK_STOCK_EXECUTE, N_("_Send Article"), "<control>Return", N_("Send Article Now"), G_CALLBACK(do_send) },
-    { "set-charset", NULL, N_("Set Character _Encoding..."), NULL, NULL, G_CALLBACK(do_charset) },
+    { "set-charset", 0, N_("Set Character _Encoding..."), 0, 0, G_CALLBACK(do_charset) },
     { "save-draft", GTK_STOCK_SAVE, N_("Sa_ve Draft"), "<control>s", N_("Save as a Draft for Future Posting"), G_CALLBACK(do_save) },
     { "open-draft", GTK_STOCK_OPEN, N_("_Open Draft..."), "<control>o", N_("Open an Article Draft"), G_CALLBACK(do_open) },
-    { "close", GTK_STOCK_CLOSE, NULL, NULL, NULL, G_CALLBACK(do_close) },
-    { "cut", GTK_STOCK_CUT, NULL, NULL, NULL, G_CALLBACK(do_cut) },
-    { "copy", GTK_STOCK_COPY, NULL, NULL, NULL, G_CALLBACK(do_copy) },
-    { "paste", GTK_STOCK_PASTE, NULL, NULL, NULL, G_CALLBACK(do_paste) },
-    { "rot13", GTK_STOCK_REFRESH, N_("_Rot13"), NULL, N_("Rot13 Selected Text"), G_CALLBACK(do_rot13) },
-    { "run-editor", GTK_STOCK_JUMP_TO, N_("Run _Editor"), "<control>e", NULL, G_CALLBACK(do_edit) },
-    { "manage-profiles", GTK_STOCK_EDIT, N_("Edit P_osting Profiles"), NULL, NULL, G_CALLBACK(do_profiles) }
+    { "close", GTK_STOCK_CLOSE, 0, 0, 0, G_CALLBACK(do_close) },
+    { "cut", GTK_STOCK_CUT, 0, 0, 0, G_CALLBACK(do_cut) },
+    { "copy", GTK_STOCK_COPY, 0, 0, 0, G_CALLBACK(do_copy) },
+    { "paste", GTK_STOCK_PASTE, 0, 0, 0, G_CALLBACK(do_paste) },
+    { "rot13", GTK_STOCK_REFRESH, N_("_Rot13"), 0, N_("Rot13 Selected Text"), G_CALLBACK(do_rot13) },
+    { "run-editor", GTK_STOCK_JUMP_TO, N_("Run _Editor"), "<control>e", 0, G_CALLBACK(do_edit) },
+    { "manage-profiles", GTK_STOCK_EDIT, N_("Edit P_osting Profiles"), 0, 0, G_CALLBACK(do_profiles) }
   };
 
   GtkToggleActionEntry toggle_entries[] =
   {
-    { "wrap", GTK_STOCK_JUSTIFY_FILL, N_("_Wrap Text"), NULL, NULL, G_CALLBACK(do_wrap), true },
-    { "always-run-editor", NULL, N_("Always Run Editor"), NULL, NULL, G_CALLBACK(do_edit2), false },
-    { "remember-charset", NULL, N_("Remember Character Encoding for this Group"), NULL, NULL, G_CALLBACK(on_remember_charset_toggled), true },
-    { "spellcheck", NULL, N_("Check _Spelling"), NULL, NULL, G_CALLBACK(on_spellcheck_toggled), true }
+    { "wrap", GTK_STOCK_JUSTIFY_FILL, N_("_Wrap Text"), 0, 0, G_CALLBACK(do_wrap), true },
+    { "always-run-editor", 0, N_("Always Run Editor"), 0, 0, G_CALLBACK(do_edit2), false },
+    { "remember-charset", 0, N_("Remember Character Encoding for this Group"), 0, 0, G_CALLBACK(on_remember_charset_toggled), true },
+    { "spellcheck", 0, N_("Check _Spelling"), 0, 0, G_CALLBACK(on_spellcheck_toggled), true }
   };
 
-  void add_widget (GtkUIManager* merge, GtkWidget* widget, gpointer vbox)
+  void add_widget (GtkUIManager*, GtkWidget* widget, gpointer vbox)
   {
     if (GTK_IS_TOOLBAR (widget)) {
       GtkWidget * handle_box = gtk_handle_box_new ();
@@ -314,7 +318,7 @@ PostUI :: rot13_selection ()
 
 namespace
 {
-  gboolean delete_event_cb (GtkWidget *w, GdkEvent *e, gpointer user_data)
+  gboolean delete_event_cb (GtkWidget*, GdkEvent*, gpointer user_data)
   {
     static_cast<PostUI*>(user_data)->close_window ();
     return true; // don't invoke the default handler that destroys the widget
@@ -501,9 +505,9 @@ namespace
       for (int i='0'; i<='9'; ++i) keep.insert(i); // always okay
       for (int i='a'; i<='z'; ++i) keep.insert(i); // always okay
       for (int i='A'; i<='Z'; ++i) keep.insert(i); // always okay
-      for (char *pch="$-_.+!*'(),"; *pch; ++pch) keep.insert(*pch); // okay in the right context
-      for (char *pch="$&+,/:;=?@"; *pch; ++pch) keep.erase(*pch); // reserved
-      for (char *pch="()"; *pch; ++pch) keep.erase(*pch); // gives thunderbird problems?
+      for (const char *pch="$-_.+!*'(),"; *pch; ++pch) keep.insert(*pch); // okay in the right context
+      for (const char *pch="$&+,/:;=?@"; *pch; ++pch) keep.erase(*pch); // reserved
+      for (const char *pch="()"; *pch; ++pch) keep.erase(*pch); // gives thunderbird problems?
     }
 
     std::string out;
@@ -924,7 +928,7 @@ PostUI :: new_message_from_ui (Mode mode)
   // headers from the ui: To
   const StringView to (gtk_entry_get_text (GTK_ENTRY(_to_entry)));
   if (!to.empty())
-    g_mime_message_add_recipients_from_string (msg, GMIME_RECIPIENT_TYPE_TO, to.str);
+    g_mime_message_add_recipients_from_string (msg, (char*)GMIME_RECIPIENT_TYPE_TO, to.str);
 
   // headers from the ui: Newsgroups
   const StringView groups (gtk_entry_get_text (GTK_ENTRY(_groups_entry)));
@@ -1072,7 +1076,6 @@ PostUI :: create_body_widget (GtkTextBuffer*& buf, GtkWidget*& view, const Prefs
 {
   const int WRAP_COLS = 75;
   const int VIEW_COLS = 80;
-  const int VIEW_ROWS = 30;
 
   view = gtk_text_view_new ();
   buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW(view));
@@ -1096,8 +1099,7 @@ PostUI :: create_body_widget (GtkTextBuffer*& buf, GtkWidget*& view, const Prefs
   s.assign (VIEW_COLS, 'A');
   pango_layout_set_text (layout, s.c_str(), s.size());
   pango_layout_get_extents (layout, &r, 0);
-  gtk_widget_set_size_request (view, PANGO_PIXELS(r.width),
-                                     PANGO_PIXELS(r.height*VIEW_ROWS));
+  gtk_widget_set_size_request (view, PANGO_PIXELS(r.width), -1 );
  
   // set the rest of the text view's policy 
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(view), GTK_WRAP_WORD);
@@ -1340,23 +1342,40 @@ PostUI :: apply_profile_to_body ()
   }
 
   // remove the last signature
-  int index;
-  if (!GNKSA :: find_signature_delimiter (body, index))
-    index = body.size();
-  StringView v (body.c_str(), index);
-  v.rtrim ();
-  body.assign (v.str, v.len);
-  if (!body.empty())
-    body += "\n\n"; // add linefeed to the last quoted line, and add a blank line between quoted and new text
-  const int insert_pos = body.size();
+  std::string::size_type pos = body.rfind (_current_signature);
+  if (pos != body.npos) {
+    body.resize (pos);
+    StringView v (body);
+    v.rtrim ();
+    body.assign (v.str, v.len);
+  }
 
-  // insert the new signature
+  // get the new signature
   std::string sig;
-  load_signature (profile.signature_file, profile.sig_type, sig);
-  if (!sig.empty()) {
+  if (profile.use_sigfile) {
+    load_signature (profile.signature_file, profile.sig_type, sig);
     int ignored;
     if (GNKSA::find_signature_delimiter (sig, ignored) == GNKSA::SIG_NONE)
-      body += "\n\n-- \n";
+      sig = std::string("\n\n-- \n") + sig;
+  }
+  _current_signature = sig;
+
+  // add the new signature, and empty space between the
+  // body (if present), the insert point, and the new signature
+  int insert_pos;
+  if (body.empty() && sig.empty()) {
+    insert_pos = 0;
+  } else if (body.empty()) {
+    insert_pos = 0;
+    body = "\n\n";
+    body += sig;
+  } else if (sig.empty()) {
+    body += "\n\n";
+    insert_pos = body.size();
+  } else {
+    body += "\n\n";
+    insert_pos = body.size();
+    body += "\n\n";
     body += sig;
   }
 
@@ -1428,7 +1447,7 @@ namespace
     delete static_cast<PostUI*>(p);
   }
 
-  void on_from_combo_changed (GtkComboBox *widget, gpointer user_data)
+  void on_from_combo_changed (GtkComboBox*, gpointer user_data)
   {
     static_cast<PostUI*>(user_data)->apply_profile ();
   }
@@ -1548,7 +1567,7 @@ PostUI :: set_message (GMimeMessage * message)
  * will work properly.
  */
 void
-PostUI :: body_view_realized_cb (GtkWidget * w, gpointer self_gpointer)
+PostUI :: body_view_realized_cb (GtkWidget*, gpointer self_gpointer)
 {
   PostUI * self = static_cast<PostUI*>(self_gpointer);
   self->set_wrap_mode (self->_prefs.get_flag ("compose-wrap-enabled", true));
@@ -1592,7 +1611,7 @@ PostUI :: group_entry_changed_idle (gpointer ui_gpointer)
 }
 
 void
-PostUI :: group_entry_changed_cb (GtkEditable * w, gpointer ui_gpointer)
+PostUI :: group_entry_changed_cb (GtkEditable*, gpointer ui_gpointer)
 {
   PostUI * ui (static_cast<PostUI*>(ui_gpointer));
   unsigned int& tag (ui->_group_entry_changed_idle_tag);
@@ -1606,7 +1625,7 @@ PostUI :: group_entry_changed_cb (GtkEditable * w, gpointer ui_gpointer)
 
 namespace
 {
-  static void render_from (GtkCellLayout    * cell_layout,
+  static void render_from (GtkCellLayout    * ,
                            GtkCellRenderer  * renderer,
                            GtkTreeModel     * model,
                            GtkTreeIter      * iter,
@@ -1750,6 +1769,7 @@ PostUI :: create_extras_tab ()
 
   w = _followupto_entry = gtk_entry_new ();
   gtk_label_set_mnemonic_widget (GTK_LABEL(l), w);
+  /* i18n: "poster" is a key used by many newsreaders.  probably safest to keep this key in english. */
   gtk_tooltips_set_tip (GTK_TOOLTIPS(_ttips), w, _("The newsgroups where replies to your message should go.  This is only needed if it differs from the \"Newsgroups\" header.\n\nTo direct all replies to your email address, use \"Followup-To: poster\""), 0);
   gtk_table_attach (GTK_TABLE(t), w, 1, 2, row, row+1, fe, fill, 0, 0);
 
@@ -1859,6 +1879,7 @@ PostUI :: PostUI (GtkWindow    * parent,
   g_signal_connect (_root, "delete-event", G_CALLBACK(delete_event_cb), this);
   gtk_window_set_role (GTK_WINDOW(_root), "pan-post-window");
   gtk_window_set_title (GTK_WINDOW(_root), _("Post Article"));
+  gtk_window_set_default_size (GTK_WINDOW(_root), -1, 450);
   g_object_set_data_full (G_OBJECT(_root), "post-ui", this, delete_post_ui);
   if (parent) {
     gtk_window_set_transient_for (GTK_WINDOW(_root), parent);
