@@ -28,7 +28,7 @@ extern "C" {
   #include <gtk/gtk.h>
 }
 #include <pan/general/debug.h>
-#include <pan/general/foreach.h>
+#include <pan/general/macros.h>
 #include <pan/usenet-utils/gnksa.h>
 #include "hig.h"
 #include "pad.h"
@@ -222,23 +222,6 @@ ProfileDialog :: ~ProfileDialog ()
 {
 }
 
-namespace
-{
-  void message_dialog_set_text (GtkMessageDialog * dialog,
-                                const char * primary,
-                                const char * secondary)
-  {
-#if GTK_CHECK_VERSION(2,6,0)
-    gtk_message_dialog_set_markup (dialog, primary);
-    gtk_message_dialog_format_secondary_text (dialog, "%s", secondary);
-#else
-    char * pch = g_strdup_printf ("<b>%s</b>\n\n%s", primary, secondary);
-    gtk_message_dialog_set_markup (dialog, pch);
-    g_free (pch);
-#endif
-  }
-}
-
 /*static*/ bool
 ProfileDialog :: run_until_valid_or_cancel (ProfileDialog& pd)
 {
@@ -261,9 +244,9 @@ ProfileDialog :: run_until_valid_or_cancel (ProfileDialog& pd)
         GTK_MESSAGE_ERROR,
         GTK_BUTTONS_CLOSE,
         NULL);
-      message_dialog_set_text (GTK_MESSAGE_DIALOG(d),
-                               _("Invalid email address."),
-                               _("Please use an address of the form joe@somewhere.org"));
+      HIG :: message_dialog_set_text (GTK_MESSAGE_DIALOG(d),
+                                      _("Invalid email address."),
+                                      _("Please use an address of the form joe@somewhere.org"));
       gtk_dialog_run (GTK_DIALOG(d));
       gtk_widget_destroy (d);
       gtk_widget_grab_focus (pd._address_entry);
@@ -436,14 +419,14 @@ ProfilesDialog :: refresh_buttons ()
 
 namespace
 {
-  void profiles_tree_view_selection_changed_cb (GtkTreeSelection * selection, gpointer user_data)
+  void profiles_tree_view_selection_changed_cb (GtkTreeSelection *, gpointer user_data)
   {
     ProfilesDialog *d = (ProfilesDialog *)user_data;
     d->refresh_buttons ();
   }
-  void tree_view_row_activated_cb (GtkTreeView        * view,
-                                   GtkTreePath        * path,
-                                   GtkTreeViewColumn  * col,
+  void tree_view_row_activated_cb (GtkTreeView        * ,
+                                   GtkTreePath        * ,
+                                   GtkTreeViewColumn  * ,
                                    gpointer             user_data)
   {
     on_edit_button (NULL, user_data);
@@ -500,7 +483,6 @@ ProfilesDialog :: ProfilesDialog (const Data& data, Profiles &profiles, GtkWindo
   // add button
   w = gtk_button_new_from_stock (GTK_STOCK_ADD);
   gtk_box_pack_start (GTK_BOX (bbox), w, false, false, 0);
-  gtk_tooltips_set_tip (tips, w, _("Add a New Profile"), NULL);
   gtk_signal_connect (GTK_OBJECT(w), "clicked", GTK_SIGNAL_FUNC(on_add_button), this);
 
   // edit button
@@ -511,13 +493,11 @@ ProfilesDialog :: ProfilesDialog (const Data& data, Profiles &profiles, GtkWindo
 #endif
   _edit_button = w;
   gtk_box_pack_start (GTK_BOX (bbox), w, false, false, 0);
-  gtk_tooltips_set_tip (tips, w, _("Edit the selected profile"), NULL);
   gtk_signal_connect (GTK_OBJECT(w), "clicked", GTK_SIGNAL_FUNC(on_edit_button), this);
 
   // remove button
   _remove_button = w = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
   gtk_box_pack_start (GTK_BOX (bbox), w, false, false, 0);
-  gtk_tooltips_set_tip (tips, w, _("Remove the selected profile"), NULL);
   gtk_signal_connect (GTK_OBJECT(w), "clicked", GTK_SIGNAL_FUNC(on_delete_button), this);
 
   // set sensitive buttons
