@@ -1,4 +1,3 @@
-extern const guint8 icon_article_new[]; 
 extern const guint8 icon_article_read[]; 
 extern const guint8 icon_article_unread[]; 
 extern const guint8 icon_binary_complete[]; 
@@ -17,11 +16,10 @@ extern const guint8 icon_filter[];
 extern const guint8 icon_filter_only_attachments[]; 
 extern const guint8 icon_filter_only_cached[]; 
 extern const guint8 icon_filter_only_me[]; 
-extern const guint8 icon_filter_only_new[]; 
+extern const guint8 icon_filter_only_unread[]; 
 extern const guint8 icon_filter_only_watched[]; 
 extern const guint8 icon_get_dialog[]; 
 extern const guint8 icon_get_flagged[]; 
-extern const guint8 icon_get_new[]; 
 extern const guint8 icon_get_selected[]; 
 extern const guint8 icon_get_subscribed[]; 
 extern const guint8 icon_layout_1[]; 
@@ -29,15 +27,12 @@ extern const guint8 icon_layout_2[];
 extern const guint8 icon_layout_3[]; 
 extern const guint8 icon_layout_4[]; 
 extern const guint8 icon_layout_5[]; 
-extern const guint8 icon_online[]; 
 extern const guint8 icon_pan_logo[]; 
 extern const guint8 icon_pan_about_logo[]; 
 extern const guint8 icon_pan[]; 
 extern const guint8 icon_read_group[]; 
 extern const guint8 icon_read_more[]; 
 extern const guint8 icon_read_less[]; 
-extern const guint8 icon_read_new_article[]; 
-extern const guint8 icon_read_new_thread[]; 
 extern const guint8 icon_read_unread_article[]; 
 extern const guint8 icon_read_unread_thread[]; 
 extern const guint8 icon_score[]; 
@@ -48,5 +43,3 @@ extern const guint8 icon_mozilla_smile[];
 extern const guint8 icon_mozilla_surprised[]; 
 extern const guint8 icon_mozilla_tongueout[]; 
 extern const guint8 icon_mozilla_wink[]; 
-extern const guint8 icon_zoom_in[]; 
-extern const guint8 icon_zoom_out[]; 
