@@ -20,6 +20,7 @@
 #include <config.h>
 #include <cassert>
 #include <cstdarg>
+#include <cstdlib> // abort, atoi, strtoul
 extern "C" {
   #include <glib.h>
   #include <glib/gi18n.h>
@@ -63,6 +64,7 @@ namespace
 
       SERVER_READY               = 200,
       SERVER_READY_NO_POSTING    = 201,
+      SERVER_READY_STREAMING_OK  = 203,
 
       GOODBYE                    = 205,
 
@@ -113,7 +115,7 @@ NNTP :: fire_done_func (Health health, const StringView& response)
 ***/
 
 bool
-NNTP :: on_socket_response (Socket * sock, const StringView& line_in)
+NNTP :: on_socket_response (Socket * sock UNUSED, const StringView& line_in)
 {
    enum State { CMD_FAIL, CMD_DONE, CMD_MORE, CMD_NEXT, CMD_RETRY };
    State state;
@@ -147,6 +149,7 @@ NNTP :: on_socket_response (Socket * sock, const StringView& line_in)
    {
       case SERVER_READY:
       case SERVER_READY_NO_POSTING:
+      case SERVER_READY_STREAMING_OK:
          state = CMD_DONE;
          break;
 
@@ -288,13 +291,13 @@ NNTP :: on_socket_response (Socket * sock, const StringView& line_in)
 }
 
 void
-NNTP :: on_socket_abort (Socket * sock)
+NNTP :: on_socket_abort (Socket * sock UNUSED)
 {
    fire_done_func (ERR_NETWORK, StringView());
 }
 
 void
-NNTP :: on_socket_error (Socket * sock)
+NNTP :: on_socket_error (Socket * sock UNUSED)
 {
    _socket_error = true;
    fire_done_func (ERR_NETWORK, StringView());
