@@ -29,8 +29,8 @@ extern "C" {
 }
 #include <pan/general/debug.h>
 #include <pan/general/file-util.h>
-#include <pan/general/foreach.h>
 #include <pan/general/log.h>
+#include <pan/general/macros.h>
 #include <pan/usenet-utils/mime-utils.h>
 #include <pan/data/article-cache.h>
 #include "decoder.h"
@@ -96,27 +96,24 @@ TaskArticle :: TaskArticle (const ServerRank          & server_rank,
   }
 
   unsigned long need_bytes(0), all_bytes(0);
-  foreach_const (Article::parts_t, article.parts, it)
+  for (Article::part_iterator i(article.pbegin()), e(article.pend()); i!=e; ++i)
   {
-    all_bytes += it->bytes;
+    all_bytes += i.bytes();
+    const std::string mid (i.mid ());
+    if (cache.contains (mid))
+      continue;
 
-    const std::string mid (it->get_message_id (article.message_id));
-    if (!it->empty() && !cache.contains (mid))
-    {
-      need_bytes += it->bytes;
-
-      Needed n;
-      n.part = *it;
-
-      // if we can keep the article-number from the main xref, do so.
-      // otherwise plug in `0' as a null article-number and we'll use
-      // `ARTICLE message-id' instead when talking to the server.
-      foreach_const (quarks_t, servers, sit)
-        foreach_const (quarks_t, groups, git)
-          n.xref.insert (*sit, *git, mid==article.message_id.to_string() ? article.xref.find_number(*sit,*git) : 0);
-
-      _needed.push_back (n);
-    }
+    need_bytes += i.bytes();
+    Needed n;
+    n.message_id = mid;
+    n.bytes = i.bytes();
+    // if we can keep the article-number from the main xref, do so.
+    // otherwise plug in `0' as a null article-number and we'll use
+    // `ARTICLE message-id' instead when talking to the server.
+    foreach_const (quarks_t, servers, sit)
+      foreach_const (quarks_t, groups, git)
+        n.xref.insert (*sit, *git, mid==article.message_id.to_string() ? article.xref.find_number(*sit,*git) : 0);
+    _needed.push_back (n);
   }
 
   // initialize our progress status...
@@ -140,14 +137,14 @@ TaskArticle :: ~TaskArticle ()
 }
 
 void
-TaskArticle :: update_work ()
+TaskArticle :: update_work (NNTP * checkin_pending)
 {
   // which servers could we use right now?
   int working (0);
   quarks_t servers;
   foreach (needed_t, _needed, nit) {
     Needed& n (*nit);
-    if (n.nntp)
+    if (n.nntp && n.nntp!=checkin_pending)
       ++working;
     else {
       quarks_t tmpservers;
@@ -180,7 +177,7 @@ TaskArticle :: get_bytes_remaining () const
 {
   unsigned long bytes (0);
   foreach_const (needed_t, _needed, it) // parts not fetched yet...
-    bytes += (it->part.bytes - it->buf.size());
+    bytes += (it->bytes - it->buf.size());
   return bytes;
 }
 
@@ -199,10 +196,9 @@ TaskArticle :: use_nntp (NNTP * nntp)
 
   if (!needed)
   {
-    // couldn't find any work for this nntp...
-    // maybe our needs-work list is out of date, so call update_work()
-    // before giving the nntp back.
-    update_work ();
+    // std::cerr << LINE_ID << " hmm, why did I ask for server " << nntp->_server
+    //           << "?  I can't use it.  I'd better refresh my worklist." << std::endl;
+    update_work (nntp);
     check_in (nntp, OK);
   }
   else
@@ -216,7 +212,7 @@ TaskArticle :: use_nntp (NNTP * nntp)
     if (number)
       nntp->article (group, number, this);
     else
-      nntp->article (group, needed->part.get_message_id(_article.message_id).c_str(), this);
+      nntp->article (group, needed->message_id.c_str(), this);
     update_work ();
   }
 }
@@ -253,10 +249,8 @@ TaskArticle :: on_nntp_line  (NNTP               * nntp,
 void
 TaskArticle :: on_nntp_done  (NNTP             * nntp,
                               Health             health,
-                              const StringView & response)
+                              const StringView & response UNUSED)
 {
-  bool err_local = false;
-
   // find the Needed using this nntp...
   needed_t::iterator it;
   for (it=_needed.begin(); it!=_needed.end(); ++it)
@@ -264,30 +258,42 @@ TaskArticle :: on_nntp_done  (NNTP             * nntp,
       break;
   assert (it != _needed.end());
 
-  //std::cerr << LINE_ID << ' ' << it->part.message_id << " from " << nntp->_server << ": " << (health==OK ? "yes" : "no") << std::endl;
-
   if (health == OK) { // if download succeeded, save it in the cache
     const StringView view (&it->buf.front(), it->buf.size());
-    if (!_cache.add (it->part.get_message_id(_article.message_id), view))
-      err_local = true;
+    if (!_cache.add (it->message_id, view))
+      health = ERR_LOCAL;
   }
 
-  if (health == ERR_COMMAND) // if server doesn't have that article...
-    it->xref.remove_server (nntp->_server);
+  // std::cerr << LINE_ID << ' ' << it->message_id << " from " << nntp->_server << ": health " << health << std::endl;
 
-  // if we got it or still have other options, we're okay
-  _state.set_health (health==ERR_COMMAND && it->xref.empty() ? ERR_COMMAND : OK);
+  switch (health)
+  {
+    case OK: // if we got the article successfully...
+      _needed.erase (it);
+      break;
 
-  if (health==OK)
-    _needed.erase (it);
-  else {
-    Needed::buf_t tmp;
-    it->buf.swap (tmp); // deallocates the space...
-    it->nntp = 0;
+    case ERR_NETWORK: // if the network is bad...
+    case ERR_LOCAL: // ...or if we got it but couldn't save it
+      it->reset ();
+      break;
+
+    case ERR_COMMAND: // if this one server doesn't have this part...
+      it->xref.remove_server (nntp->_server);
+      if (!it->xref.empty())
+        it->reset ();
+      else { // if none of our servers have this part, but keep going --
+             // an incomplete file gives us more PAR2 blocks than a missing one.
+        Log :: add_err_va (
+          _("Article \"%s\" is incomplete -- the news server(s) don't have part %s"),
+          _article.subject.c_str(),
+          it->message_id.c_str());
+        _needed.erase (it);
+      }
+      break;
   }
-
-  update_work ();
-  check_in (nntp, err_local ? ERR_LOCAL : health);
+  
+  update_work (nntp);
+  check_in (nntp, health);
 }
 
 /***
@@ -329,11 +335,11 @@ TaskArticle :: on_worker_done (bool cancelled)
     // the decoder is done... catch up on all housekeeping
     // now that we're back in the main thread.
 
-    foreach_const(std::list<std::string>, _decoder->log_severe, it)
+    foreach_const(Decoder::log_t, _decoder->log_severe, it)
       Log :: add_err(it->c_str());
-    foreach_const(std::list<std::string>, _decoder->log_errors, it)
+    foreach_const(Decoder::log_t, _decoder->log_errors, it)
       Log :: add_err(it->c_str());
-    foreach_const(std::list<std::string>, _decoder->log_infos, it)
+    foreach_const(Decoder::log_t, _decoder->log_infos, it)
       Log :: add_info(it->c_str());
 
     if (_decoder->mark_read)
