@@ -81,7 +81,7 @@
 #include <fptools.h>
 #include <uustring.h>
 
-char * uulib_id = "$Id: uulib.c 2 2006-10-02 20:45:58Z csk $";
+char * uulib_id = "$Id: uulib.c 260 2007-05-04 23:32:54Z csk $";
 
 #ifdef SYSTEM_WINDLL
 BOOL _export WINAPI 
@@ -328,7 +328,7 @@ UUBusyPoll (void)
     }
   }
 #else
-  time_t now;
+  time_t now = time (NULL);
   long msecs;
 
   if (uu_BusyCallback) {
@@ -336,7 +336,6 @@ UUBusyPoll (void)
       msecs = 1;
     }
     else {
-      now   = time(NULL);
       msecs = 1000 * (now - uu_last_secs);
     }
 
