@@ -57,7 +57,7 @@
 #include <fptools.h>
 #include <uustring.h>
 
-char * uunconc_id = "$Id: uunconc.c,v 1.38 2004/03/01 22:52:27 fp Exp $";
+char * uunconc_id = "$Id: uunconc.c 260 2007-05-04 23:32:54Z csk $";
 
 /* for braindead systems */
 #ifndef SEEK_SET
@@ -1205,8 +1205,8 @@ UUDecodePart (FILE *datain, FILE *dataout, int *state,
 	  count  = UUDecodeLine (line, oline, method);
 	  if (method == YENC_ENCODED) {
 	    if (yepartends)
-	      yepartcrc = crc32(yepartcrc, oline, count);
-	    yefilecrc = crc32(yefilecrc, oline, count);
+	      yepartcrc = crc32(yepartcrc, (unsigned char*)oline, count);
+	    yefilecrc = crc32(yefilecrc, (unsigned char*)oline, count);
 	    yepartsize += count;
 	  }
 	  vlc++; lc[1]++;
@@ -1326,8 +1326,12 @@ UUDecode (uulist *data)
   if (data->state & UUFILE_NODATA)
     return UURET_NODATA;
 
-  if (data->state & UUFILE_NOBEGIN && !uu_desperate)
-    return UURET_NODATA;
+  if (data->state & UUFILE_NOBEGIN) {
+    if (!uu_desperate)
+      return UURET_NODATA;
+    UUMessage (uunconc_id, __LINE__, UUMSG_WARNING,
+               uustring(S_DATA_SUSPICIOUS));
+  }
 
   if (data->uudet == PT_ENCODED)
     mode = "wt";	/* open text files in text mode */
@@ -1374,8 +1378,10 @@ UUDecode (uulist *data)
    * it in desperate mode
    */
 
-  if ((data->state & UUFILE_NOBEGIN) && uu_desperate)
+  if ((data->state & UUFILE_NOBEGIN) && uu_desperate) {
+    UUMessage (uunconc_id, __LINE__, UUMSG_WARNING, uustring(S_DATA_SUSPICIOUS));
     state = DATA;
+  }
 
   (void) UUDecodeLine (NULL, NULL, 0);                   /* init */
   (void) UUbhwrite    (NULL, 0, 0, NULL);                /* dito */
@@ -1415,10 +1421,16 @@ UUDecode (uulist *data)
 
   iter = data->thisfile;
   while (iter) {
-    if (part != -1 && iter->partno != part+1 && !uu_desperate)
-      break;
-    else
-      part = iter->partno;
+
+    if (part==-1 && iter->partno!=1)
+       UUMessage (uunconc_id, __LINE__, UUMSG_WARNING, "Missing everything before part #%d", iter->partno);
+    if (part!=-1 && iter->partno!=part+1) {
+      if (!uu_desperate)
+        break;
+      UUMessage (uunconc_id, __LINE__, UUMSG_ERROR,
+                 uustring(S_PART_MISSING), part);
+    }
+    part = iter->partno;
 
     if (iter->data->sfname == NULL) {
       iter = iter->NEXT;
