@@ -57,7 +57,7 @@
 #include <fptools.h>
 #include <uustring.h>
 
-char * uuscan_id = "$Id: uuscan.c 300 2007-05-26 16:28:55Z csk $";
+char * uuscan_id = "$Id: uuscan.c 316 2007-08-01 17:26:35Z csk $";
 
 /*
  * Header fields we recognize as such. See RFC822. We add "From ",
@@ -627,7 +627,7 @@ ScanData (FILE *datei, char *fname, int *errcode,
   long preheaders=0, oldposition;
   long yefilesize=0, yepartends=0;
   size_t dcc, bhopc;
-  int oldcheckheaders;
+  int oldcheckheaders = 0;
 
   *errcode = UURET_OK;
   (void) UUDecodeLine (NULL, NULL, 0);          /* init */
